# python-autoclass

[![Build Status](https://travis-ci.org/smarie/python-autoclass.svg?branch=master)](https://travis-ci.org/smarie/python-autoclass) [![Tests Status](https://smarie.github.io/python-autoclass/junit/junit-badge.svg?dummy=8484744)](https://smarie.github.io/python-autoclass/junit/report.html) [![codecov](https://codecov.io/gh/smarie/python-autoclass/branch/master/graph/badge.svg)](https://codecov.io/gh/smarie/python-autoclass) [![Documentation](https://img.shields.io/badge/docs-latest-blue.svg)](https://smarie.github.io/python-autoclass/) [![PyPI](https://img.shields.io/badge/PyPI-autoclass-blue.svg)](https://pypi.python.org/pypi/autoclass/)[![downloads](https://img.shields.io/badge/downloads%2011%2F17-10k-brightgreen.svg)](https://kirankoduru.github.io/python/pypi-stats.html)

Helps you to write compact python classes.

The documentation for users is available here: [https://smarie.github.io/python-autoclass/](https://smarie.github.io/python-autoclass/)

A readme for developers is available here: [https://github.com/smarie/python-autoclass](https://github.com/smarie/python-autoclass)
